pub struct WeightTensor {
pub data: Vec<f32>,
pub shape: Vec<usize>,
pub name: String,
}Expand description
Weight tensor for pruning operations
Represents a named tensor with shape information, suitable for layer-wise or global pruning operations.
Fields
data: Vec<f32>Weight data in row-major order
shape: Vec<usize>Shape of the tensor (e.g., [out_channels, in_channels, kernel_h, kernel_w])
name: StringLayer name for identification
Implementations
Sourceimpl WeightTensor
impl WeightTensor
Sourcepub fn new(data: Vec<f32>, shape: Vec<usize>, name: String) -> Self
pub fn new(data: Vec<f32>, shape: Vec<usize>, name: String) -> Self
Creates a new weight tensor
Sourcepub fn validate(&self) -> Result<()>
pub fn validate(&self) -> Result<()>
Validates that shape matches data length
Errors
Returns an error if shape product does not match data length
Sourcepub fn statistics(&self) -> WeightStatistics
pub fn statistics(&self) -> WeightStatistics
Returns statistics about the weight distribution