pub struct BatchProcessor<M: Model> { /* private fields */ }Expand description
Batch processor for efficient model serving
Implementations
Sourceimpl<M: Model> BatchProcessor<M>
impl<M: Model> BatchProcessor<M>
Sourcepub fn new(model: M, config: BatchConfig) -> Self
pub fn new(model: M, config: BatchConfig) -> Self
Creates a new batch processor
Sourcepub fn infer(&self, input: RasterBuffer) -> Result<RasterBuffer>
pub fn infer(&self, input: RasterBuffer) -> Result<RasterBuffer>
Submits a request for batch inference
When dynamic batching is enabled, requests are collected and processed
together to improve throughput. For single requests, use DynamicBatchProcessor
for more advanced batching with priority queuing and adaptive sizing.
Errors
Returns an error if inference fails
Sourcepub fn infer_batch(
&self,
inputs: Vec<RasterBuffer>,
) -> Result<Vec<RasterBuffer>>
pub fn infer_batch( &self, inputs: Vec<RasterBuffer>, ) -> Result<Vec<RasterBuffer>>
Sourcepub fn infer_batch_with_progress(
&self,
inputs: Vec<RasterBuffer>,
show_progress: bool,
) -> Result<Vec<RasterBuffer>>
pub fn infer_batch_with_progress( &self, inputs: Vec<RasterBuffer>, show_progress: bool, ) -> Result<Vec<RasterBuffer>>
Sourcepub fn stats(&self) -> BatchStats
pub fn stats(&self) -> BatchStats
Returns the batch statistics
Sourcepub fn reset_stats(&self)
pub fn reset_stats(&self)
Resets the statistics